<?php
/**
 * Telephone
 *
 * @author David Eder <david@eder.us>
 * @copyright 2004 David Eder
 * @package docsis_config
 * @version .3
 */

 /**
  */
  require_once(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'docsis_common.php');

  define('DOCSIS_TELEPHONE', 15);
  define('DOCSIS_TELEPHONE_PROVIDER', 2);
  define('DOCSIS_TELEPHONE_NUMBER_1', 3);
  define('DOCSIS_TELEPHONE_NUMBER_2', 4);
  define('DOCSIS_TELEPHONE_NUMBER_3', 5);
  define('DOCSIS_TELEPHONE_CON_THRESH', 6);
  define('DOCSIS_TELEPHONE_LOGIN', 7);
  define('DOCSIS_TELEPHONE_PASSWORD', 8);
  define('DOCSIS_TELEPHONE_DHCP_AUTH', 9);
  define('DOCSIS_TELEPHONE_DHCP_SERVER', 10);
  define('DOCSIS_TELEPHONE_RADIUS_REALM', 11);
  define('DOCSIS_TELEPHONE_PPP_AUTH', 12);
  define('DOCSIS_TELEPHONE_DDI_TIMER_THESH', 13);

 /**
  * Telephone
  *
  * @package docsis_config
  */
  class docsis_telephone extends docsis_encoder_complex
  {
   /**
    * Constructor
    *
    * @param int $code docsis code
    * @param array $value predefined values
    */
    function docsis_telephone($code=DOCSIS_TELEPHONE, $value=array())
    {
      parent::docsis_encoder_complex($code, $value);
    }

   /**
    * Set Service Provider Name - docsis 1.0
    *
    * @param string $value
    */
    function set_provider($value)
    {
      $this->value[DOCSIS_TELEPHONE_PROVIDER] = new docsis_encoder_string(DOCSIS_TELEPHONE_PROVIDER, $value);
    }

   /**
    * Set Telephone Number 1 - docsis 1.0
    *
    * @param string $value
    */
    function set_number_1($value)
    {
      $this->value[DOCSIS_TELEPHONE_NUMBER_1] = new docsis_encoder_string(DOCSIS_TELEPHONE_NUMBER_1, $value);
    }

   /**
    * Set Telephone Number 2 - docsis 1.0
    *
    * @param string $value
    */
    function set_number_2($value)
    {
      $this->value[DOCSIS_TELEPHONE_NUMBER_2] = new docsis_encoder_string(DOCSIS_TELEPHONE_NUMBER_2, $value);
    }

   /**
    * Set Telephone Number 3 - docsis 1.0
    *
    * @param string $value
    */
    function set_number_3($value)
    {
      $this->value[DOCSIS_TELEPHONE_NUMBER_3] = new docsis_encoder_string(DOCSIS_TELEPHONE_NUMBER_3, $value);
    }

   /**
    * Set Connection Threshold - docsis 1.0
    *
    * Retry count threshold for registration attempts.
    *
    * @param int $retries from 0 to 255
    */
    function set_con_thresh($retries)
    {
      $this->value[DOCSIS_TELEPHONE_CON_THRESH] = new docsis_encoder_uchar(DOCSIS_TELEPHONE_CON_THRESH, $retries);
    }

   /**
    * Set Login Username - docsis 1.0
    *
    * Login username to be used for PPP authentification.
    *
    * @param string $value
    */
    function set_login($value)
    {
      $this->value[DOCSIS_TELEPHONE_LOGIN] = new docsis_encoder_string(DOCSIS_TELEPHONE_LOGIN, $value);
    }

   /**
    * Set Login Password - docsis 1.0
    *
    * Login password to be used for PPP authentification.
    *
    * @param string $value
    */
    function set_password($value)
    {
      $this->value[DOCSIS_TELEPHONE_PASSWORD] = new docsis_encoder_string(DOCSIS_TELEPHONE_PASSWORD, $value);
    }

   /**
    * Set DHCP Authenticate - docsis 1.0
    *
    * @param boolean $value
    */
    function set_dhcp_auth($value)
    {
      if($value < 0 || $value > 1) trigger_error('DHCP Auth must be 0 or 1', E_USER_WARNING);
      $this->value[DOCSIS_TELEPHONE_DHCP_AUTH] = new docsis_encoder_uchar(DOCSIS_TELEPHONE_DHCP_AUTH, $value);
    }

   /**
    * Set DHCP Server - docsis 1.0
    *
    * @param string $value ip address of DHCP server.
    */
    function set_dhcp_server($value)
    {
      $this->value[DOCSIS_TELEPHONE_DHCP_SERVER] = new docsis_encoder_ip(DOCSIS_TELEPHONE_DHCP_SERVER, $value);
    }

   /**
    * Set RADIUS Realm - docsis 1.0
    *
    * @param string $value radius realm name to be used for PPP authentification.
    */
    function set_radius_realm($value)
    {
      $this->value[DOCSIS_TELEPHONE_RADIUS_REALM] = new docsis_encoder_string(DOCSIS_TELEPHONE_RADIUS_REALM, $value);
    }

   /**
    * Set PPP Authenticate - docsis 1.0
    *
    * @param boolean $value
    */
    function set_ppp_auth($value)
    {
      $this->value[DOCSIS_TELEPHONE_PPP_AUTH] = new docsis_encoder_uchar(DOCSIS_TELEPHONE_PPP_AUTH, $value);
    }

   /**
    * Set Demand Dial Inactivity Time Threshold - docsis 1.0
    *
    * The demand dial inactivity timer monitors network activity at the CM.  The purpose is to limit the CM (upsteam) network connectivity to
    * periods of time when connectivity is required.
    *
    * @param int $value seconds of inactive networking time allowed to elapse before hanging up a telephone connection at the CM. Zero represent non-use.
    */
    function set_ddi_timer_thresh($value)
    {
      $this->value[DOCSIS_TELEPHONE_DDI_TIMER_THESH] = new docsis_encoder_uint(DOCSIS_TELEPHONE_DDI_TIMER_THESH, $value);
    }
  }
?>
