<?php
/**
 * MTA Config Writer
 *
 * @author David Eder <david@eder.us>
 * @copyright 2004 David Eder
 * @package mta_config
 * @version .3
 */

 /**
  */
  require_once(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'docsis_config.php');

 /**
  * MTA Config Writer
  *
  * @package docsis_config
  */
  class mta_config extends docsis_encoder_complex
  {
   /**
    * Constructor
    *
    * @param int $code docsis code
    * @param array predefined values
    */
    function mta_config($code=0, $value=array())
    {
      parent::docsis_encoder_complex($code, $value);
    }

   /**
    * Add SNMP MIB Object
    *
    * This object allows arbtrary SNMP MIB objects to be Set via the TFTP-Registration process.
    *
    * The cable modem must treat this object as if it were part of an SNMP Set Request with the following caveats:
    * <ul>
    *   <li>The CM must treat the request as fully authorized (it cannot refuse the request for lack of privilege).</li>
    *   <li>SNMP Write-Control provisions do not apply</li>
    *   <li>No SNMP response is generated by the CM.</li>
    * </ul>
    *
    * All such Sets must be treated as simultaneous.
    *
    * Example values:
    * <ul>
    *   <li>$value = new rfc1155_Integer($value);</li>
    *   <li>$value = new rfc1155_Counter($value);</li>
    *   <li>$value = new rfc1155_Guage($value);</li>
    *   <li>$value = new rfc1155_TimeTicks($value);</li>
    *   <li>$value = new rfc1155_OctetString(hexbin($value)); // hex string</li>
    *   <li>$value = new rfc1155_OctetString($value);</li>
    *   <li>$value = new rfc1155_IPAddress($value);</li>
    *   <li>$value = new rfc1155_ObjectID($value);</li>
    * </ul>
    *
    * @param string $oid
    * @param rfc1155_Asn1Object $value
    */
    function add_snmp_object($oid, $value)
    {
      // must be a rfc1157_VarBind
      $varbind = new rfc1157_VarBind(new rfc1155_ObjectID($oid), $value);
      $varbind = $varbind->encode(); //Contents();
      $this->value[DOCSIS_SNMP_MIB_OBJECT][] = new docsis_encoder_string(DOCSIS_SNMP_MIB_OBJECT, $varbind);
    }

    function set_mta_config_delimiter($value)
    {
      if($value < 1 || $value > 255) trigger_error('MTA Config Delimiter must be 1 to 255', E_USER_WARNING);
      $this->value[DOCSIS_MTA_CONFIG_DELIMITER] = new docsis_encoder_uchar(DOCSIS_MTA_CONFIG_DELIMITER, $value);
    }

    function encode()
    {
      $ds = new docsis_encoder_uchar(DOCSIS_MTA_CONFIG_DELIMITER, 1);
      $de = new docsis_encoder_uchar(DOCSIS_MTA_CONFIG_DELIMITER, 255);
      return $ds->encode() . substr(parent::encode(), 2) . $de->encode();
    }
  }
?>
